modepy
======

:mod:`modepy` helps you create well-behaved high-order
discretizations on simplices (i.e. triangles and tetrahedra).
These are a key building block for high-order unstructured
discretizations, as often used in a finite element context.
It closely follows the approach taken in the book

  Hesthaven, Jan S., and Tim Warburton. "Nodal Discontinuous Galerkin Methods:
  Algorithms, Analysis, and Applications". 1st ed. Springer, 2007.
  `Book web page <http://nudg.org>`_

Resources:

* `documentation <http://documen.tician.de/modepy>`_
* `wiki home page <http://wiki.tiker.net/ModePy>`_
* `source code via git <http://github.com/inducer/modepy>`_
